unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, VCLTee.TeeTools,
  VCLTee.TeEngine, VCLTee.Series, Vcl.ExtCtrls, VCLTee.TeeProcs, VCLTee.Chart;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Series1: TLineSeries;
    lintlRightSide: TColorLineTool;
    anntoolRightside: TAnnotationTool;
    procedure Chart1BeforeDrawSeries(Sender: TObject);
  private
    { Private declarations }
    procedure UpdateAnnotationPosition(aChart: TChart);
  public
    { Public declarations }
    constructor Create(aOwner: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

uses
  math;

{$R *.dfm}

const
  CLR_RIGHT_SIDE = clGreen;
  NUM_POINTS = 10;
  RIGHT_SIDE_DESCRIP = 'Right Side'#13'Of Chart';

{ TForm1 }

constructor TForm1.Create(aOwner: TComponent);
begin
  inherited;

  anntoolRightSide.Text := RIGHT_SIDE_DESCRIP;
  anntoolRightSide.Shape.Frame.Color := CLR_RIGHT_SIDE;
  anntoolRightSide.Shape.ShapeStyle := fosRoundRectangle;

  lintlRightSide.Pen.Color := CLR_RIGHT_SIDE;


  Series1.FillSampleValues(NUM_POINTS);

  lintlRightSide.Value := NUM_POINTS - 1;
end;

procedure TForm1.Chart1BeforeDrawSeries(Sender: TObject);
begin
  UpdateAnnotationPosition(Sender as TChart);
end;

procedure TForm1.UpdateAnnotationPosition(aChart: TChart);
var
  lChartTool: TTeeCustomTool;
  lIdx: Integer;

  procedure SetLeftPos(aMiddle: double; aAnnTool: TAnnotationTool);
  const
    H_MARGIN = 50;
  var
    lLeft: Integer;
    lR: TRect;
    lAnnWidth: Integer;
  begin
    if not aAnnTool.Active then
      exit;

    lLeft :=  aChart.BottomAxis.CalcXPosValue(aMiddle);
    lR := aAnnTool.Bounds;
    lAnnWidth := lR.Right- lR.Left + 1;
    aAnnTool.Shape.Left := lLeft - (Max(0, lAnnWidth) div 2);
    if aAnnTool.Shape.Left + aAnnTool.Shape.Width > (aChart.Width - H_MARGIN) then
      aAnnTool.Shape.Left := aChart.Width - H_MARGIN - aAnnTool.Shape.Width;

    aAnnTool.Shape.Top := 30;
  end;

  function GetAnnotationTool(aTitle: String): TAnnotationTool;
  var
    I: Integer;
    lComp: TComponent;
  begin
    for I := 0 to ComponentCount - 1 do    // Iterate
    begin
      lComp := Components[I];
      if (lComp is TAnnotationTool) and
        (TAnnotationTool(lComp).Text = aTitle) then
        exit(TAnnotationTool(lComp))
    end;
    result := nil;
  end;

  function GetLineTool(aColor: TColor): TColorLineTool;
  var
    I: Integer;
    lComp: TComponent;
  begin
    for I := 0 to ComponentCount - 1 do    // Iterate
    begin
      lComp := Components[I];
      if (lComp is TColorLineTool) and
        (TColorLineTool(lComp).Pen.Color = aColor) then
        exit(TColorLineTool(lComp));
    end;
    result := nil;
  end;

var
  lAnnotate: TAnnotationTool;
  lLineTool: TColorLineTool;
  lRects: array of TRect;
begin
  SetLength(lRects, 1);
  lLineTool := GetLineTool(CLR_RIGHT_SIDE);
  lAnnotate := GetAnnotationTool(RIGHT_SIDE_DESCRIP);
  SetLeftPos(lLineTool.Value, lAnnotate);
end;


end.
